Datasets used in ISLP
=====================

A list of data sets needed to perform the labs and exercises in this
textbook. All data sets are available in the `ISLP`
package, with the exception of `USArrests`
which is part of the base `R` distribution, but accessible from
`statsmodels`.

.. toctree::

   datasets/Auto
   datasets/Bikeshare
   datasets/Boston
   datasets/BrainCancer
   datasets/Caravan
   datasets/Carseats
   datasets/College
   datasets/Credit
   datasets/Default
   datasets/Fund
   datasets/Hitters
   datasets/Khan
   datasets/NCI60
   datasets/NYSE
   datasets/OJ
   datasets/Portfolio
   datasets/Publication
   datasets/Smarket
   datasets/USArrests
   datasets/Wage
   datasets/Weekly
